@@ -14,12 +14,11 @@
 
 import json
 import os
-import requests
-import six
-from six.moves import urllib
+import urllib
 
 from oslo_concurrency import lockutils
 from oslo_log import log as logging
+import requests
 
 from os_brick import exception
 from os_brick.i18n import _
@@ -154,7 +153,7 @@ class ScaleIOConnector(base.BaseLinuxConnector):
     # NOTE: Usually 3 retries is enough to find the volume.
     # If there are network issues, it could take much longer. Set
     # the max retries to 15 to make sure we can find the volume.
-    @utils.retry(exceptions=exception.BrickException,
+    @utils.retry(exception.BrickException,
                  retries=15,
                  backoff_rate=1)
     def _wait_for_volume_path(self, path):
@@ -337,7 +336,7 @@ class ScaleIOConnector(base.BaseLinuxConnector):
         return device_info
 
     @utils.trace
-    @lockutils.synchronized('scaleio', 'scaleio-')
+    @lockutils.synchronized('scaleio', 'scaleio-', external=True)
     def connect_volume(self, connection_properties):
         """Connect the volume.
 
@@ -451,7 +450,7 @@ class ScaleIOConnector(base.BaseLinuxConnector):
         return device_info
 
     @utils.trace
-    @lockutils.synchronized('scaleio', 'scaleio-')
+    @lockutils.synchronized('scaleio', 'scaleio-', external=True)
     def disconnect_volume(self, connection_properties, device_info,
                           force=False, ignore_errors=False):
         """Disconnect the ScaleIO volume.
@@ -537,7 +536,7 @@ class ScaleIOConnector(base.BaseLinuxConnector):
         (out, _err) = self._execute('blockdev', '--getsize64',
                                     device, run_as_root=True,
                                     root_helper=self._root_helper)
-        var = six.text_type(out.strip())
+        var = str(out.strip())
         LOG.debug("Device %(dev)s size: %(var)s",
                   {'dev': device, 'var': var})
         if var.isnumeric():
