@@ -41,6 +41,8 @@ class ZeroIntervalLoopingCall(loopingcall.FixedIntervalLoopingCall):
 
 class ConnectorUtilsTestCase(test_base.TestCase):
 
+    @mock.patch.object(nvmeof.NVMeOFConnector, '_get_system_uuid',
+                       return_value=None)
     @mock.patch.object(nvmeof.NVMeOFConnector, '_get_host_uuid',
                        return_value=None)
     @mock.patch.object(nvmeof.NVMeOFConnector, '_get_host_nqn',
@@ -59,6 +61,7 @@ class ConnectorUtilsTestCase(test_base.TestCase):
                                              mock_wwnns, mock_wwpns,
                                              mock_initiator,
                                              mock_nqn,
+                                             mock_hostuuid,
                                              mock_sysuuid,
                                              host='fakehost'):
         props_actual = connector.get_connector_properties('sudo',
@@ -103,20 +106,28 @@ class ConnectorUtilsTestCase(test_base.TestCase):
     def test_brick_get_connector_properties(self):
         self._test_brick_get_connector_properties(False, False, False)
 
+    @mock.patch.object(priv_rootwrap, 'custom_execute',
+                       side_effect=OSError(2))
     @mock.patch.object(priv_rootwrap, 'execute', return_value=('', ''))
-    def test_brick_get_connector_properties_multipath(self, mock_execute):
+    def test_brick_get_connector_properties_multipath(self, mock_execute,
+                                                      mock_custom_execute):
         self._test_brick_get_connector_properties(True, True, True)
         mock_execute.assert_called_once_with('multipathd', 'show', 'status',
                                              run_as_root=True,
                                              root_helper='sudo')
+        mock_custom_execute.assert_called_once_with('nvme', 'version')
 
+    @mock.patch.object(priv_rootwrap, 'custom_execute',
+                       side_effect=OSError(2))
     @mock.patch.object(priv_rootwrap, 'execute',
                        side_effect=putils.ProcessExecutionError)
-    def test_brick_get_connector_properties_fallback(self, mock_execute):
+    def test_brick_get_connector_properties_fallback(self, mock_execute,
+                                                     mock_custom_execute):
         self._test_brick_get_connector_properties(True, False, False)
         mock_execute.assert_called_once_with('multipathd', 'show', 'status',
                                              run_as_root=True,
                                              root_helper='sudo')
+        mock_custom_execute.assert_called_once_with('nvme', 'version')
 
     @mock.patch.object(priv_rootwrap, 'execute',
                        side_effect=putils.ProcessExecutionError)
@@ -197,9 +208,9 @@ class ConnectorTestCase(test_base.TestCase):
     @mock.patch('sys.platform', 'win32')
     def test_get_connector_mapping_win32(self):
         mapping_win32 = connector.get_connector_mapping()
-        self.assertTrue('ISCSI' in mapping_win32)
-        self.assertTrue('RBD' in mapping_win32)
-        self.assertFalse('STORPOOL' in mapping_win32)
+        self.assertIn('ISCSI', mapping_win32)
+        self.assertIn('RBD', mapping_win32)
+        self.assertNotIn('STORPOOL', mapping_win32)
 
     @mock.patch('os_brick.initiator.connector.platform.machine')
     def test_get_connector_mapping(self, mock_platform_machine):
